@@ -74,7 +74,6 @@ winGetWindowInfo(WindowPtr pWin)
         hwnd = pWinScreen->hwndScreen;
 
         pScreenInfo = pWinScreen->pScreenInfo;
-#ifdef XWIN_MULTIWINDOW
         /* check for multiwindow mode */
         if (pScreenInfo->fMultiWindow) {
             winWindowPriv(pWin);
@@ -99,25 +98,6 @@ winGetWindowInfo(WindowPtr pWin)
 
             return hwnd;
         }
-#endif
-#ifdef XWIN_MULTIWINDOWEXTWM
-        /* check for multiwindow external wm mode */
-        if (pScreenInfo->fMWExtWM) {
-            win32RootlessWindowPtr pRLWinPriv
-                = (win32RootlessWindowPtr) RootlessFrameForWindow(pWin, FALSE);
-
-            if (pRLWinPriv == NULL) {
-                ErrorF("winGetWindowInfo: window has no privates\n");
-                return hwnd;
-            }
-
-            if (pRLWinPriv->hWnd != NULL) {
-                /* copy window handle */
-                hwnd = pRLWinPriv->hWnd;
-            }
-            return hwnd;
-        }
-#endif
     }
     else {
         ScreenPtr pScreen = g_ScreenInfo[0].pScreen;
@@ -142,15 +122,8 @@ winCheckScreenAiglxIsSupported(ScreenPtr pScreen)
     winPrivScreenPtr pWinScreen = winGetScreenPriv(pScreen);
     winScreenInfoPtr pScreenInfo = pWinScreen->pScreenInfo;
 
-#ifdef XWIN_MULTIWINDOW
     if (pScreenInfo->fMultiWindow)
         return TRUE;
-#endif
-
-#ifdef XWIN_MULTIWINDOWEXTWM
-    if (pScreenInfo->fMWExtWM)
-        return TRUE;
-#endif
 
     return FALSE;
 }
