@@ -42,13 +42,16 @@
 #include "winprefs.h"
 #include "winmsg.h"
 #include "inputstr.h"
-#include "wmutil/keyboard.h"
 #include <dwmapi.h>
 
 #ifndef WM_DWMCOMPOSITIONCHANGED
 #define WM_DWMCOMPOSITIONCHANGED 0x031e
 #endif
 
+#ifndef WM_GETDPISCALEDSIZE
+#define WM_GETDPISCALEDSIZE 0x02E4
+#endif
+
 extern void winUpdateWindowPosition(HWND hWnd, HWND * zstyle);
 
 /*
@@ -306,28 +309,35 @@ void
 winAdjustXWindowState(winPrivScreenPtr s_pScreenPriv, winWMMessageRec *wmMsg)
 {
     /* Do nothing if window has not yet been given initial state */
-    if (!GetProp(wmMsg->hwndWindow, WIN_STATE_PROP))
+    int current_state = (intptr_t)GetProp(wmMsg->hwndWindow, WIN_STATE_PROP);
+    if (!current_state)
         return;
 
-    wmMsg->msg = WM_WM_CHANGE_STATE;
+    int state = -1;
     if (IsIconic(wmMsg->hwndWindow)) {
-        wmMsg->dwID = 3; // IconicState
-        winSendMessageToWM(s_pScreenPriv->pWMInfo, wmMsg);
+        state = 3; // IconicState
     }
     else if (IsZoomed(wmMsg->hwndWindow)) {
-        wmMsg->dwID = 2; // ZoomState
-        winSendMessageToWM(s_pScreenPriv->pWMInfo, wmMsg);
+        state = 2; // ZoomState
     }
     else if (IsWindowVisible(wmMsg->hwndWindow)) {
-        wmMsg->dwID = 1; // NormalState
-        winSendMessageToWM(s_pScreenPriv->pWMInfo, wmMsg);
+        state = 1; // NormalState
      }
     else {
         /* Only the client, not the user can Withdraw windows, so it doesn't make
            much sense to handle that state here, and anything else is an
            unanticapted state. */
         ErrorF("winAdjustXWindowState - Unknown state for %p\n", wmMsg->hwndWindow);
+        return;
     }
+
+    /* Do nothing if window state isn't changing */
+    if (current_state == state)
+        return;
+
+    wmMsg->msg = WM_WM_CHANGE_STATE;
+    wmMsg->dwID = state;
+    winSendMessageToWM(s_pScreenPriv->pWMInfo, wmMsg);
 }
 
 /* Undocumented */
@@ -362,8 +372,6 @@ CheckForAlpha(HWND hWnd, WindowPtr pWin, winScreenInfo *pScreenInfo)
 
     if (doOnce)
         {
-            /* XXX: when mingw-w64-headers 5.0 is available, just include
-               versionhelper.h and use the appropriate macros here */
             OSVERSIONINFOEX osvi = {0};
             osvi.dwOSVersionInfoSize = sizeof(osvi);
             GetVersionEx((LPOSVERSIONINFO)&osvi);
@@ -468,8 +476,8 @@ winTopLevelWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
 #endif
 
     /*
-       If this is WM_CREATE, set up the Windows window properties which point to X window information,
-       before we populate other local variables...
+       If this is WM_CREATE, set up the Windows window properties which point to
+       X window information, before we populate local convenience variables...
      */
     if (message == WM_CREATE) {
         SetProp(hwnd,
@@ -838,6 +846,16 @@ winTopLevelWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
         /* Add the keyboard hook if possible */
         if (g_fKeyboardHookLL)
             g_fKeyboardHookLL = winInstallKeyboardHookLL();
+
+        /* Tell our Window Manager thread to activate the window */
+        if (fWMMsgInitialized)
+            {
+                wmMsg.msg = WM_WM_ACTIVATE;
+                /* don't focus override redirect windows (e.g. menus) */
+                if (!pWin || !pWin->overrideRedirect)
+                    winSendMessageToWM(s_pScreenPriv->pWMInfo, &wmMsg);
+            }
+
         return 0;
 
     case WM_KILLFOCUS:
@@ -847,9 +865,13 @@ winTopLevelWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
         /* Remove our keyboard hook if it is installed */
         winRemoveKeyboardHookLL();
 
-        /* Revert the X focus as well, but only if the Windows focus is going to another window */
-        if (!wParam && pWin)
-            DeleteWindowFromAnyEvents(pWin, FALSE);
+        /* Revert the X focus as well */
+        if (fWMMsgInitialized)
+            {
+                wmMsg.msg = WM_WM_ACTIVATE;
+                wmMsg.iWindow = 0;
+                winSendMessageToWM(s_pScreenPriv->pWMInfo, &wmMsg);
+            }
 
         return 0;
 
@@ -933,26 +955,8 @@ winTopLevelWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
         /* Pass the message to the root window */
         SendMessage(hwndScreen, message, wParam, lParam);
 
-        if (LOWORD(wParam) != WA_INACTIVE) {
-            /* Raise the window to the top in Z order */
-            /* ago: Activate does not mean putting it to front! */
-            /*
-               wmMsg.msg = WM_WM_RAISE;
-               if (fWMMsgInitialized)
-               winSendMessageToWM (s_pScreenPriv->pWMInfo, &wmMsg);
-             */
-
-            /* Tell our Window Manager thread to activate the window */
-            wmMsg.msg = WM_WM_ACTIVATE;
-            if (fWMMsgInitialized)
-                if (!pWin || !pWin->overrideRedirect)   /* for OOo menus */
-                    winSendMessageToWM(s_pScreenPriv->pWMInfo, &wmMsg);
-        }
-        /* Prevent the mouse wheel from stalling when another window is minimized */
-        if (HIWORD(wParam) == 0 && LOWORD(wParam) == WA_ACTIVE &&
-            (HWND) lParam != NULL && (HWND) lParam != GetParent(hwnd))
-            SetFocus(hwnd);
-        return 0;
+        /* Allow DefWindowProc to SetFocus() as needed */
+        break;
 
     case WM_ACTIVATEAPP:
         /*
@@ -1269,16 +1273,22 @@ winTopLevelWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
         }
         break;
 
-    case WM_ASYNCMOVE:
-        winAdjustWindowsWindow(pWin, hwnd);
-        break;
-
     case WM_DWMCOMPOSITIONCHANGED:
         /* This message is only sent on Vista/W7 */
         CheckForAlpha(hwnd, pWin, s_pScreenInfo);
 
         return 0;
 
+    case WM_GETDPISCALEDSIZE:
+        winDebug("winTopLevelWindowProc - WM_GETDPISCALEDSIZE\n");
+        // We don't change the lParam SIZE, so the Window retains the same size
+        // in pixels (rather than getting linearly scaled by the dpi value)
+        return TRUE;
+
+    case WM_ASYNCMOVE:
+        winAdjustWindowsWindow(pWin, hwnd);
+        break;
+
     default:
         break;
     }
@@ -1347,61 +1357,12 @@ winChildWindowProc(HWND hwnd, UINT message, WPARAM wParam, LPARAM lParam)
     case WM_ASYNCMOVE:
         winAdjustWindowsWindow(pWin, hwnd);
         break;
+
+    case WM_GETDPISCALEDSIZE:
+        // We don't change the lParam SIZE, so the Window retains the same size
+        // in pixels (rather than getting linearly scaled by the dpi value)
+        return TRUE;
     }
 
     return DefWindowProc(hwnd, message, wParam, lParam);
 }
-
-void
-winUpdateWindowPosition(HWND hWnd, HWND * zstyle)
-{
-    int iX, iY, iWidth, iHeight;
-    int iDx, iDy;
-    RECT rcNew;
-    WindowPtr pWin = GetProp(hWnd, WIN_WINDOW_PROP);
-    DrawablePtr pDraw = NULL;
-
-    if (!pWin)
-        return;
-    pDraw = &pWin->drawable;
-    if (!pDraw)
-        return;
-
-    /* Get the X and Y location of the X window */
-    iX = pWin->drawable.x + GetSystemMetrics(SM_XVIRTUALSCREEN);
-    iY = pWin->drawable.y + GetSystemMetrics(SM_YVIRTUALSCREEN);
-
-    /* Get the height and width of the X window */
-    iWidth = pWin->drawable.width;
-    iHeight = pWin->drawable.height;
-
-    /* Setup a rectangle with the X window position and size */
-    SetRect(&rcNew, iX, iY, iX + iWidth, iY + iHeight);
-
-    winDebug("winUpdateWindowPosition - drawable extent (%d, %d)-(%d, %d)\n",
-             (int)rcNew.left, (int)rcNew.top, (int)rcNew.right, (int)rcNew.bottom);
-
-    AdjustWindowRectEx(&rcNew, GetWindowLongPtr(hWnd, GWL_STYLE), FALSE,
-                       GetWindowLongPtr(hWnd, GWL_EXSTYLE));
-
-    /* Don't allow window decoration to disappear off to top-left as a result of this adjustment */
-    if (rcNew.left < GetSystemMetrics(SM_XVIRTUALSCREEN)) {
-        iDx = GetSystemMetrics(SM_XVIRTUALSCREEN) - rcNew.left;
-        rcNew.left += iDx;
-        rcNew.right += iDx;
-    }
-
-    if (rcNew.top < GetSystemMetrics(SM_YVIRTUALSCREEN)) {
-        iDy = GetSystemMetrics(SM_YVIRTUALSCREEN) - rcNew.top;
-        rcNew.top += iDy;
-        rcNew.bottom += iDy;
-    }
-
-    winDebug("winUpdateWindowPosition - Window extent (%d, %d)-(%d, %d)\n",
-             (int)rcNew.left, (int)rcNew.top, (int)rcNew.right, (int)rcNew.bottom);
-
-    /* Position the Windows window */
-    SetWindowPos(hWnd, *zstyle, rcNew.left, rcNew.top,
-                 rcNew.right - rcNew.left, rcNew.bottom - rcNew.top, 0);
-
-}
