@@ -50,16 +50,13 @@ SOFTWARE.
 #include "misc.h"
 #include <stdarg.h>
 #include <stdint.h>
+#if defined(HAVE_REALLOCARRAY)
+#include <stdlib.h>       /* for reallocarray */
+#endif
 #include <string.h>
 #ifdef MONOTONIC_CLOCK
 #include <time.h>
 #endif
-#if defined(HAVE_LIBBSD) && defined(HAVE_REALLOCARRAY)
-#include <bsd/stdlib.h>       /* for reallocarray */
-#endif
-#if defined(HAVE_LIBBSD) && defined(HAVE_STRLCPY)
-#include <bsd/string.h>       /* for strlcpy, strlcat */
-#endif
 
 #include <signal.h>
 
@@ -129,8 +126,6 @@ extern _X_EXPORT int WriteToClient(ClientPtr /*who */ , int /*count */ ,
 
 extern _X_EXPORT void ResetOsBuffers(void);
 
-extern _X_EXPORT void InitConnectionLimits(void);
-
 extern _X_EXPORT void NotifyParentProcess(void);
 
 extern _X_EXPORT void CreateWellKnownSockets(void);
@@ -306,8 +301,8 @@ OsRegisterSigWrapper(OsSigWrapperPtr newWrap);
 
 extern _X_EXPORT int auditTrailLevel;
 
-extern _X_EXPORT void
-LockServer(void);
+extern _X_EXPORT Bool
+LockServer(int);
 extern _X_EXPORT void
 UnlockServer(void);
 
@@ -534,6 +529,13 @@ GenerateAuthorization(unsigned int /* name_length */ ,
 extern _X_EXPORT int
 ddxProcessArgument(int /*argc */ , char * /*argv */ [], int /*i */ );
 
+#define CHECK_FOR_REQUIRED_ARGUMENTS(num)  \
+    do if (((i + num) >= argc) || (!argv[i + num])) {                   \
+        UseMsg();                                                       \
+        FatalError("Required argument to %s not specified\n", argv[i]); \
+    } while (0)
+
+
 extern _X_EXPORT void
 ddxUseMsg(void);
 
@@ -558,8 +560,6 @@ enum ExitCode {
     EXIT_ERR_DRIVERS = 3,
 };
 
-extern _X_EXPORT void
-AbortDDX(enum ExitCode error);
 extern _X_EXPORT void
 ddxGiveUp(enum ExitCode error);
 extern _X_EXPORT void
@@ -719,17 +719,23 @@ LogPrintMarkers(void);
 extern _X_EXPORT void
 xorg_backtrace(void);
 
+#ifdef __CYGWIN__
 extern _X_EXPORT void
 xorg_crashreport(int signo, siginfo_t *sip, void *sigcontext);
 
 extern _X_EXPORT void
 xorg_crashreport_init(const char *logfile);
+#endif
 
 extern _X_EXPORT int
 os_move_fd(int fd);
 
 #include <signal.h>
 
+#if defined(WIN32) && !defined(__CYGWIN__)
+typedef _sigset_t sigset_t;
+#endif
+
 extern _X_EXPORT int
 xthread_sigmask(int how, const sigset_t *set, sigset_t *oldest);
 
