@@ -195,6 +195,8 @@ Bool CoreDump;
 
 Bool enableIndirectGLX = FALSE;
 
+Bool AllowByteSwappedClients = TRUE;
+
 #ifdef PANORAMIX
 Bool PanoramiXExtensionDisabledHack = FALSE;
 #endif
@@ -248,9 +250,11 @@ OsSignal(int sig, OsSigHandlerPtr handler)
 #endif
 
 #ifndef LOCK_SERVER
-void
-LockServer(void)
-{}
+Bool
+LockServer(int num)
+{
+    return TRUE;
+}
 
 void
 UnlockServer(void)
@@ -263,11 +267,12 @@ Bool nolock = FALSE;
 /*
  * LockServer --
  *      Check if the server lock file exists.  If so, check if the PID
- *      contained inside is valid.  If so, then die.  Otherwise, create
- *      the lock file containing the PID.
+ *      contained inside is valid.  Otherwise, create the lock file containing
+ *      the PID.  Return a bool indicating if lock was taken.  Die if problems
+ *      occur manipulating the lock file.
  */
-void
-LockServer(void)
+Bool
+LockServer(int num)
 {
     char tmp[PATH_MAX], pid_str[12];
     int lfd, i, haslock, l_pid, t;
@@ -276,11 +281,11 @@ LockServer(void)
     char port[20];
 
     if (nolock || NoListenAll)
-        return;
+        return TRUE;
     /*
      * Path names
      */
-    snprintf(port, sizeof(port), "%d", atoi(display));
+    snprintf(port, sizeof(port), "%d", num);
     len = strlen(LOCK_PREFIX) > strlen(LOCK_TMP_PREFIX) ? strlen(LOCK_PREFIX) :
         strlen(LOCK_TMP_PREFIX);
     len += strlen(tmppath) + strlen(port) + strlen(LOCK_SUFFIX) + 1;
@@ -376,10 +381,7 @@ LockServer(void)
                  * Process is still active.
                  */
                 unlink(tmp);
-                FatalError
-                    ("Server is already active for display %s\n%s %s\n%s\n",
-                     port, "\tIf this server is no longer running, remove",
-                     lockFile, "\tand start again.");
+                return FALSE;
             }
         }
         else {
@@ -393,6 +395,7 @@ LockServer(void)
     if (!haslock)
         FatalError("Could not create server lock file: %s\n", lockFile);
     StillLocking = FALSE;
+    return TRUE;
 }
 
 /*
@@ -406,7 +409,6 @@ UnlockServer(void)
         return;
 
     if (!StillLocking) {
-
         (void) unlink(lockFile);
     }
 }
@@ -529,6 +531,8 @@ UseMsg(void)
     ErrorF("-br                    create root window with black background\n");
     ErrorF("+bs                    enable any backing store support\n");
     ErrorF("-bs                    disable any backing store support\n");
+    ErrorF("+byteswappedclients    Allow clients with endianess different to that of the server\n");
+    ErrorF("-byteswappedclients    Prohibit clients with endianess different to that of the server\n");
     ErrorF("-c                     turns off key-click\n");
     ErrorF("c #                    key-click volume (0-100)\n");
     ErrorF("-cc int                default color visual class\n");
@@ -726,6 +730,11 @@ ProcessCommandLine(int argc, char *argv[])
             else
                 UseMsg();
         }
+        else if (strcmp(argv[i], "-byteswappedclients") == 0) {
+            AllowByteSwappedClients = FALSE;
+        } else if (strcmp(argv[i], "+byteswappedclients") == 0) {
+            AllowByteSwappedClients = TRUE;
+        }
         else if (strcmp(argv[i], "-br") == 0);  /* default */
         else if (strcmp(argv[i], "+bs") == 0)
             enableBackingStore = TRUE;
@@ -768,9 +777,6 @@ ProcessCommandLine(int argc, char *argv[])
         else if (strcmp(argv[i], "-displayfd") == 0) {
             if (++i < argc) {
                 displayfd = atoi(argv[i]);
-#ifdef LOCK_SERVER
-                nolock = TRUE;
-#endif
             }
             else
                 UseMsg();
